class EmployeeV7 {

  static final double STANDARD_HOURLY_RATE = 15.50;

  // Constructors
  EmployeeV7() {
    firstName = "Joe";
    lastName = "Jones";
    hourlyRate = STANDARD_HOURLY_RATE;
    gender = MALE;
    registerGender(MALE);
  }

  EmployeeV7(String fName, String lName, boolean gender) {
    this.firstName = fName;
    this.lastName = lName;
    this.hourlyRate = STANDARD_HOURLY_RATE;
    this.gender = gender;
    this.registerGender(gender);
  }

  EmployeeV7(String fName, String lName, double hRate, boolean gender) {
    this.firstName = fName;
    this.lastName = lName;
    this.hourlyRate = hRate;
    this.gender = gender;
    this.registerGender(gender);
  }

  // Rest of the specification is the same as in class EmployeeV7

  // Static variables
  final static boolean MALE = false;
  final static boolean FEMALE = true;
  final static double NORMAL_WORKWEEK = 37.5;
  static int numOfFemales;
  static int numOfMales;

  // Field variables
  String firstName;
  String lastName;
  double hourlyRate;
  boolean gender;

  // Instance methods

  // Determines whether an employee is a female.
  boolean isFemale() { return (gender == FEMALE); }

  // Computes the salary of an employee, based on the number of hours
  // worked during the week.
  double computeSalary(double numOfHours) {
    assert numOfHours >= 0 : "Number of hours must be >= 0";
    double weeklySalary = hourlyRate * this.NORMAL_WORKWEEK;
    if (numOfHours > EmployeeV7.NORMAL_WORKWEEK) {
      weeklySalary += 2.0 * hourlyRate * (numOfHours - NORMAL_WORKWEEK);
    }
    return weeklySalary;
  }

  // Prints the values in the field variables of an employee.
  void printState() {
    System.out.print("First name: " + firstName);
    System.out.print("\tLast name: " + lastName);
    System.out.printf("\tHourly rate: %.2f", hourlyRate);
    if (isFemale()) {
      System.out.println("\tGender: Female");
    } else {
      System.out.println("\tGender: Male");
    }
  }

  // Static methods
  // Register an employee's gender by updating the relevant counter.
  static void registerGender(boolean gender) {
    if (gender == FEMALE) {
      ++numOfFemales;
    } else {
      ++numOfMales;
    }
  }

  // Print the number of females and males registered.
  static void printStatistics() {
    System.out.println("Number of females registered: " + numOfFemales);
    System.out.println("Number of males registered: " + numOfMales);
  }
}
